@@ -118,6 +118,20 @@ Module::~Module()
 }
 
 void Module::load()
+{
+    loadSoftware();
+    loadHardware();
+}
+
+void Module::save()
+{
+}
+
+void Module::defaults()
+{
+}
+
+void Module::loadSoftware()
 {
     // NOTE: do not include globals, otherwise kdeglobals could provide values
     //       even though we only explicitly want them from our own config.
@@ -168,14 +182,16 @@ void Module::load()
 
     ui->qtLabel->setText(qVersion());
 
-
 #if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5,20,0)
     ui->frameworksLabel->setText(KCoreAddons::versionString());
 #else
     ui->frameworksLabelKey->setVisible(false);
     ui->frameworksLabel->setVisible(false);
 #endif
+}
 
+void Module::loadHardware()
+{
     struct utsname utsName;
     if(uname(&utsName) != 0) {
         ui->kernel->hide();
@@ -225,14 +241,6 @@ void Module::load()
                              : i18nc("Unknown amount of RAM", "Unknown"));
 }
 
-void Module::save()
-{
-}
-
-void Module::defaults()
-{
-}
-
 QString Module::plasmaVersion() const
 {
     const QStringList &filePaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
